0.0.9rc1.dev18
- added more scenarios - welding/gluing and lego, added new templates, runTests.py changed

0.0.9rc1.dev17
- Changes for deployment - google credentials in home folder, better error message s

0.0.9rc1.dev16
- Audio processing improved throug google cloud speech

0.0.9rc1.dev15
- Negated signal files added

0.0.9rc1.dev14
- Quicker processing, improved tests

0.0.9rc1.dev11
- Improved simple unittests

0.0.9rc1.dev9
- Improved logging system

0.0.9rc1.dev8
- Bug fixes

0.0.9rc1.dev7
- Minor bug fixes

0.0.9rc1.dev6
- Added encoding to the open file function to make it work on Win machines

0.0.9rc1.dev5
- Merge features

0.0.9rc1.dev4
- Fixed error reporting

0.0.9rc1.dev3
- Fixed formatting error

0.0.9rc1.dev2
- reworked REST API

0.0.9a3
- Minor fixes

0.0.9a1
- The first alpha version

0.0.1 Initial version
- Initial version